==> qtjambi-location-debuginfo-macos-5.15.17.jar: sources/QtJambiLocation/QGeoRouteLeg_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtLocation/qgeoroute.h>
#include <QtCore/QVariant>
#include <QtLocation/qgeoroutesegment.h>
#include <QtLocation/qgeorouterequest.h>
#include <QtCore/QList>
#include <QtPositioning/qgeorectangle.h>
#include <QtCore/QMap>
#include <QtPositioning/qgeocoordinate.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QGeoRouteLeg(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QGeoRouteLeg")
    QGeoRouteLeg *_ptr = reinterpret_cast<QGeoRouteLeg *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QGeoRouteLeg()
void __qt_construct_QGeoRouteLeg_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGeoRouteLeg()")
    Q_UNUSED(__java_arguments)
    QGeoRouteLeg *__qt_this = new(__qtjambi_ptr) QGeoRouteLeg();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QGeoRouteLeg(QGeoRouteLeg)
void __qt_construct_QGeoRouteLeg_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGeoRouteLeg(QGeoRouteLeg)")
    jobject other0 = __java_arguments[0].l;
    const QGeoRouteLeg& __qt_other0 = qtjambi_cast<const QGeoRouteLeg& >(__jni_env, other0);
    QGeoRouteLeg *__qt_this = new(__qtjambi_ptr) QGeoRouteLeg(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QGeoRouteLeg
void __qt_destruct_QGeoRouteLeg(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QGeoRouteLeg")
    reinterpret_cast<QGeoRouteLeg*>(ptr)->~QGeoRouteLeg();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QGeoRouteLeg::QGeoRouteLeg()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_initialize_1native__Lio_qt_location_QGeoRouteLeg_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGeoRouteLeg::QGeoRouteLeg()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGeoRouteLeg_0, sizeof(QGeoRouteLeg), typeid(QGeoRouteLeg), false, &deleter_QGeoRouteLeg, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGeoRouteLeg::QGeoRouteLeg(QGeoRouteLeg)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_initialize_1native__Lio_qt_location_QGeoRouteLeg_2Lio_qt_location_QGeoRouteLeg_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGeoRouteLeg::QGeoRouteLeg(QGeoRouteLeg)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGeoRouteLeg_1, sizeof(QGeoRouteLeg), typeid(QGeoRouteLeg), false, &deleter_QGeoRouteLeg, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGeoRouteLeg::legIndex()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_legIndex_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QGeoRouteLeg *__qt_this = QtJambiAPI::objectFromNativeId<QGeoRouteLeg>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoRouteLeg::legIndex()const", __qt_this)
        __java_return_value = __qt_this->legIndex();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoRouteLeg::operator=(QGeoRouteLeg)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_assign_1native_1cref_1QGeoRouteLeg__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QGeoRouteLeg *__qt_this = QtJambiAPI::objectFromNativeId<QGeoRouteLeg>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoRouteLeg::operator=(QGeoRouteLeg)", __qt_this)
        const QGeoRouteLeg& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QGeoRouteLeg>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGeoRouteLeg::overallRoute()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_overallRoute_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QGeoRouteLeg *__qt_this = QtJambiAPI::objectFromNativeId<QGeoRouteLeg>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoRouteLeg::overallRoute()const", __qt_this)
        QGeoRoute __qt_return_value = __qt_this->overallRoute();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoRouteLeg::setLegIndex(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_setLegIndex_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint idx0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QGeoRouteLeg *__qt_this = QtJambiAPI::objectFromNativeId<QGeoRouteLeg>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoRouteLeg::setLegIndex(int)", __qt_this)
        __qt_this->setLegIndex(static_cast<int>(idx0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGeoRouteLeg::setOverallRoute(QGeoRoute)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_setOverallRoute_1native_1cref_1QGeoRoute__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID route0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QGeoRouteLeg *__qt_this = QtJambiAPI::objectFromNativeId<QGeoRouteLeg>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoRouteLeg::setOverallRoute(QGeoRoute)", __qt_this)
        const QGeoRoute& __qt_route0 = QtJambiAPI::valueReferenceFromNativeId<QGeoRoute>(route0);
        __qt_this->setOverallRoute(__qt_route0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QGeoRouteLeg *__qt_this = QtJambiAPI::objectFromNativeId<QGeoRouteLeg>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QGeoRouteLeg(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QGeoRouteLeg>("QGeoRouteLeg", "io/qt/location/QGeoRouteLeg");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QGeoRouteLeg, {
        ConstructorInfo(&__qt_construct_QGeoRouteLeg_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QGeoRouteLeg_1, "Lio/qt/location/QGeoRouteLeg;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QGeoRouteLeg);
    registerMetaType<QGeoRouteLeg>("QGeoRouteLeg");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-location-debuginfo-macos-5.15.20.jar: sources/QtJambiLocation/QGeoRouteLeg_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtLocation/qgeoroute.h>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtLocation/qgeorouterequest.h>
#include <QtLocation/qgeoroutesegment.h>
#include <QtPositioning/qgeocoordinate.h>
#include <QtPositioning/qgeorectangle.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QGeoRouteLeg(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QGeoRouteLeg")
    QGeoRouteLeg *_ptr = reinterpret_cast<QGeoRouteLeg *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QGeoRouteLeg()
void __qt_construct_QGeoRouteLeg(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGeoRouteLeg()")
    Q_UNUSED(__java_arguments)
    QGeoRouteLeg *__qt_this = new(__qtjambi_ptr) QGeoRouteLeg();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QGeoRouteLeg::QGeoRouteLeg()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_initialize_1native__Lio_qt_location_QGeoRouteLeg_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGeoRouteLeg::QGeoRouteLeg()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGeoRouteLeg, sizeof(QGeoRouteLeg), typeid(QGeoRouteLeg), false, &deleter_QGeoRouteLeg, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QGeoRouteLeg(QGeoRouteLeg)
void __qt_construct_QGeoRouteLeg_cref_QGeoRouteLeg(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGeoRouteLeg(QGeoRouteLeg)")
    jobject other0 = __java_arguments[0].l;
    const QGeoRouteLeg& __qt_other0 = qtjambi_cast<const QGeoRouteLeg& >(__jni_env, other0);
    QGeoRouteLeg *__qt_this = new(__qtjambi_ptr) QGeoRouteLeg(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QGeoRouteLeg::QGeoRouteLeg(QGeoRouteLeg)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_initialize_1native__Lio_qt_location_QGeoRouteLeg_2Lio_qt_location_QGeoRouteLeg_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGeoRouteLeg::QGeoRouteLeg(QGeoRouteLeg)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGeoRouteLeg_cref_QGeoRouteLeg, sizeof(QGeoRouteLeg), typeid(QGeoRouteLeg), false, &deleter_QGeoRouteLeg, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QGeoRouteLeg
void __qt_destruct_QGeoRouteLeg(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QGeoRouteLeg")
    reinterpret_cast<QGeoRouteLeg*>(ptr)->~QGeoRouteLeg();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QGeoRouteLeg::legIndex()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_legIndex_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QGeoRouteLeg *__qt_this = QtJambiAPI::objectFromNativeId<QGeoRouteLeg>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoRouteLeg::legIndex()const", __qt_this)
        __java_return_value = __qt_this->legIndex();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoRouteLeg::operator=(QGeoRouteLeg)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_assign_1native_1cref_1QGeoRouteLeg__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QGeoRouteLeg *__qt_this = QtJambiAPI::objectFromNativeId<QGeoRouteLeg>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoRouteLeg::operator=(QGeoRouteLeg)", __qt_this)
        const QGeoRouteLeg& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QGeoRouteLeg>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGeoRouteLeg::overallRoute()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_overallRoute_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QGeoRouteLeg *__qt_this = QtJambiAPI::objectFromNativeId<QGeoRouteLeg>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoRouteLeg::overallRoute()const", __qt_this)
        QGeoRoute __qt_return_value = __qt_this->overallRoute();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoRouteLeg::setLegIndex(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_setLegIndex_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint idx0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QGeoRouteLeg *__qt_this = QtJambiAPI::objectFromNativeId<QGeoRouteLeg>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoRouteLeg::setLegIndex(int)", __qt_this)
        __qt_this->setLegIndex(static_cast<int>(idx0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGeoRouteLeg::setOverallRoute(QGeoRoute)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_setOverallRoute_1native_1cref_1QGeoRoute__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID route0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QGeoRouteLeg *__qt_this = QtJambiAPI::objectFromNativeId<QGeoRouteLeg>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoRouteLeg::setOverallRoute(QGeoRoute)", __qt_this)
        const QGeoRoute& __qt_route0 = QtJambiAPI::valueReferenceFromNativeId<QGeoRoute>(route0);
        __qt_this->setOverallRoute(__qt_route0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoRouteLeg_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QGeoRouteLeg *__qt_this = QtJambiAPI::objectFromNativeId<QGeoRouteLeg>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QGeoRouteLeg(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QGeoRouteLeg>("QGeoRouteLeg", "io/qt/location/QGeoRouteLeg");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QGeoRouteLeg, {
        ConstructorInfo(&__qt_construct_QGeoRouteLeg, nullptr)
       ,ConstructorInfo(&__qt_construct_QGeoRouteLeg_cref_QGeoRouteLeg, "Lio/qt/location/QGeoRouteLeg;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QGeoRouteLeg);
    registerMetaType<QGeoRouteLeg>("QGeoRouteLeg");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
